vietmap_flutter_plugin library

vietmap_flutter_plugin

Classes

APIKeyLimitedFailure
ApiServerFailure
ApiTimeOutFailure
Debounce
Either<L, R>
ExceptionFailure
Failure
Instructions
LatLng
A pair of latitude and longitude coordinates, stored as degrees.
Left<L, R>
NoParams
NoParams is a class that is used to represent a void parameter.
NotFoundFailure
Paths
UseCase<Type, Params>
UseCase is an abstract class that is used to define a use case.
Vietmap
VietmapAutocompleteModel
VietmapAutocompleteModel is a model class that is used to parse the response from the server.
VietmapAutocompleteModelV4
This object represents an autocomplete or geocode result in Vietmap Autocomplete API version 4.
VietMapAutoCompleteParams
Params for VietMapAutoComplete textSearch : (String) text that you want to search focusLocation : (LatLng) focus location for search, the response will be sorted by distance from this location displayType : (int) Result display type. Follow AutocompleteDisplayEnum for more detail cityId : (int) Every city has a unique ID, which is used to filter search results distId : (int) Every district has a unique ID, which is used to filter search results wardId : (int) Every ward has a unique ID, which is used to filter search results circleCenter : (LatLng) The central coordinate position of the area to be searched circleRadius : (int) The radius of the search area (in meters) cats : (String) Provide full list of POI categories layers : (String) Represent for certain type of data such as POI,ADDRESS,VILLAGE,WARD,DIST,CITY,STREET Example: VietMapAutoCompleteParams( textSearch: 'cafe', focusLocation: LatLng(10.759119885168527, 106.6759602315203), displayType: 1, cityId: 12, distId: 1292, wardId: 984332, circleCenter: LatLng(10.759119885168527, 106.6759602315203), circleRadius: 200, cats: '1002-1', layers: 'POI', );
VietmapAutocompleteParamsV4
This class represents the parameters for Vietmap Autocomplete and Geocode API version 4.
VietmapBoundaries
VietmapBoundaries is a model class that is used to parse the boundaries information from the server. This describes the administrative boundaries such as ward, district, and city.
VietmapEntryPointModel
Model class representing a Vietmap Entry Point This value will available for some special address, like airport, hotel,...
VietmapMatrixModel
Model class representing the response from Vietmap Matrix API
VietmapMatrixParams
VietmapMigrateAddressModel
This model represents the response from the Vietmap Migrate Address API.
VietmapMigrateAddressParams
This class represents the parameters for migrating addresses between old and new formats.
VietmapModel
VietmapModel is a base model class that contains the information of a Vietmap object.
VietmapPlaceModel
VietmapPlaceModel is a model class that is used to parse the response from the server.
VietmapReverseModel
VietmapReverseModelV4
This object represents a reverse geocode result in Vietmap Reverse API version 4.
VietmapReverseParams
This class represents the parameters for reverse geocoding requests in Vietmap API version 4.
VietMapRouting
VietmapRouting is a model which contains the information of a VietmapRouting response.
VietMapRoutingModel
VietMapRoutingModel is a model class that is used to parse the response from the server.
VietMapRoutingParams
Params for VietMapRouting api call
VietmapUtils