VietmapReverseParams class
This class represents the parameters for reverse geocoding requests in Vietmap API version 4.
Constructors
- VietmapReverseParams({required LatLng latLng, ReverseDisplayEnum? displayType = ReverseDisplayEnum.bothOldAndNew})
Properties
- displayType → ReverseDisplayEnum?
-
displayType is the display type of the reverse geocoding result, which determines how the result is presented.
ReverseDisplayTypeis the enum that defines the available display types.final - hashCode → int
-
The hash code for this object.
no setterinherited
- latLng → LatLng
-
latLng is the latitude and longitude of the location.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited